powered by
Generate Poisson disk samples in 2D
poisson2d(w = 10, h = 10, r = 2, k = 30L, verbosity = 0L)
data.frame with x and y coordinates. Points are returned in the order in which they were generated.
width and height of region
minimum distance between points
number of sample points to generate at each iteration. default 30
Verbosity level. default: 0
pts <- poisson2d(w = 40, h = 40, r = 1) plot(pts, asp = 1, ann = FALSE, axes = FALSE, pch = 19)
Run the code above in your browser using DataLab