powered by
Generate Poisson disk samples in 3D
poisson3d(w = 10, h = 10, d = 10, r = 4, k = 30L, verbosity = 0L)
data.frame with x, y and z coordinates. Points are returned in the order in which they were generated.
width and height and depth of region
minimum distance between points
number of sample points to generate at each iteration. default 30
Verbosity level. default: 0
poisson3d(w = 10, h = 10, d = 10, r = 5)
Run the code above in your browser using DataLab